%
% file: test_CAMS_Europe.m
%
% Examples of reading a subset of CAMS Radiation volume over Europe (Agate).
%
% authors - date: Laurent Saboret, Transvalor - 2017
%

%% Display 15 min Gc and GHI maps

clear all; close all; clc

%  Please specify here the folder containing CAMS Radiation HDF5 files
cd '/mnt/data/CAMS-Europe/'

% CAMS Radiation volume bounding box in degrees
lat_min =  34.9
lat_max =  60.1
lon_min = -10.3
lon_max =  44.7
grid_step = 0.2

% Compute CAMS Radiation volume size in pixels
width  = round((lon_max - lon_min) / grid_step) % 275
height = round((lat_max - lat_min) / grid_step) % 126

% Test bounding box in pixels (1-based).
% Feel free to change these values.
left=1
right=width
top=1
bottom=height

% Test time.
% Feel free to change these values.
% Note: Days 2005-01-11 and 2005-01-12 are missing in Apollo clouds
year=2005;
month=4;
day=1;
hr=12;
mn=00;
%
% convert test frame to julian day
jd = date2jd(year, month, day, hr, mn, 0);

% CAMS Radiation volume time start
start_jd = date2jd(2005, 1, 1, 0, 0, 0); % 2005-01-01

% Read Gc map in Wh/m2
time = (jd - start_jd)*96 + 1; 
gc_map = h5read('gc.h5', '/set', [left top time], [width height 1]);
gc_map = gc_map';
gc_map = double(gc_map);
gc_map(253 < gc_map)=nan; % remove missing and invalid values
gc_map = gc_map * 1.2; % convert to Wh/m2

% Display Gc map
figure
imagesc(gc_map); % use automatic color table
fig_title=sprintf('Gc 15 min (Wh/m2) on %04d-%02d-%02d at %02d:%02d', year, month, day, hr, mn);
title(fig_title);
colorbar

% Read GHI map in Wh/m2
time = (jd - start_jd)*96 + 1;
ghi_map = h5read('ghi.h5', '/set', [left top time], [width height 1]);
ghi_map=ghi_map';
ghi_map = double(ghi_map);
ghi_map(253 < ghi_map)=nan; % remove missing and invalid values
ghi_map = ghi_map * 1.2; % convert to Wh/m2

% Display GHI map
figure
imagesc(ghi_map, [-100, 300]); % use color table that enhances missing and invalid values
fig_title=sprintf('GHI 15 min (Wh/m2) on %04d-%02d-%02d at %02d:%02d', year, month, day, hr, mn);
title(fig_title);
colorbar


%% Display 15 min GHI as a video 

clear all; close all; clc

%  Please specify here the folder containing CAMS Radiation HDF5 files
cd '/mnt/data/CAMS-Europe/'

% CAMS Radiation volume bounding box in degrees
lat_min =  34.9
lat_max =  60.1
lon_min = -10.3
lon_max =  44.7
grid_step = 0.2

% Compute CAMS Radiation volume size in pixels
width  = round((lon_max - lon_min) / grid_step) % 275
height = round((lat_max - lat_min) / grid_step) % 126

% Test bounding box in pixels (1-based).
% Feel free to change these values.
left=1
right=width
top=1
bottom=height

% Test day.
% Feel free to change these values.
% Note: Days 2005-01-11 and 2005-01-12 are missing in Apollo clouds.
year=2005;
month=4;
day=1;
%
% convert test day to julian day
jd = date2jd(year, month, day, 0, 0, 0);

% CAMS Radiation volume time start
start_jd = date2jd(2005, 1, 1, 0, 0, 0); % 2005-01-01

% Read GHI map in Wh/m2
time = (jd - start_jd)*96 + 1; % start time
ghi_map = h5read('ghi.h5', '/set', [left top time], [width height 96]);
ghi_map = double(ghi_map);
ghi_map(253 < ghi_map)=nan; % remove missing and invalid values
ghi_map = ghi_map * 1.2; % convert to Wh/m2

% Display GHI map as a video
figure
vc(permute(ghi_map, [2 1 3]), [-100, 300]) % use color table that enhances missing and invalid values


%% Display 15 min Gc and GHI time series

clear all; close all; clc

%  Please specify here the folder containing CAMS Radiation HDF5 files
cd '/mnt/data/CAMS-Europe/'

% CAMS Radiation volume bounding box in degrees
lat_min =  34.9
lat_max =  60.1
lon_min = -10.3
lon_max =  44.7
grid_step = 0.2

% Compute CAMS Radiation volume size in pixels
width  = round((lon_max - lon_min) / grid_step) % 275
height = round((lat_max - lat_min) / grid_step) % 126

% Test location.
% Feel free to change these values.
location='Carpentras' % location name
lat=44.054
lon=5.048
%
% compute corresponding pixel in CAMS Radiation volume (1-based)
x = round((lon - lon_min)/grid_step + 0.5)
y = round((lat_max - lat)/grid_step + 0.5)
%
% compute lat/lon of pixel center
lat = lat_max - (y-0.5)*grid_step
lon = lon_min + (x-0.5)*grid_step
h = -999; % default altitude = SRTM

% Test period.
% Feel free to change these values.
% Note: Days 2005-01-11 and 2005-01-12 are missing in Apollo clouds.
year1=2005; month1=5; day1=1;
year2=2005; month2=5; day2=31;
%
yyyymmdd1 = sprintf('%04d-%02d-%02d', year1, month1, day1); % compute test period as YYYY-MM-DD
yyyymmdd2 = sprintf('%04d-%02d-%02d', year2, month2, day2);
%
jd1 = date2jd(year1, month1, day1, 0, 0, 0); % compute test period as julian days
jd2 = date2jd(year2, month2, day2, 0, 0, 0);

% CAMS Radiation volume time step
duration=15; % min
dt=duration/60.0;

% CAMS Radiation volume time start
start_jd = date2jd(2005, 1, 1, 0, 0, 0); % 2005-01-01

% Read gc time series in Wh/m2
time = (jd1 - start_jd)*96 + 1; % start time
nb_steps = (jd2 - jd1 + 1)*96
gc_time_series = h5read('gc.h5', '/set', [x y time], [1 1 nb_steps]);
gc_time_series = double(gc_time_series);
gc_time_series(253 < gc_time_series)=nan; % remove missing and invalid values
gc_time_series = gc_time_series * 1.2; % convert to Wh/m2

% Read ghi time series in Wh/m2
time = (jd1 - start_jd)*96 + 1; % start time
nb_steps = (jd2 - jd1 + 1)*96;
ghi_time_series = h5read('ghi.h5', '/set', [x y time], [1 1 nb_steps]);
ghi_time_series = double(ghi_time_series);
ghi_time_series(253 < ghi_time_series)=nan; % remove missing and invalid values
ghi_time_series = ghi_time_series * 1.2; % convert to Wh/m2

% Plot Gc
figure
plot(gc_time_series(:))
fig_title=sprintf('Gc 15 min (Wh/m2) at %s (%.3f, %.3f) from %s to %s', location, lat, lon, yyyymmdd1, yyyymmdd2);
title(fig_title);

% Plot GHI
figure
plot(ghi_time_series(:))
fig_title=sprintf('GHI 15 min (Wh/m2) at %s (%.3f, %.3f) from %s to %s', location, lat, lon, yyyymmdd1, yyyymmdd2);
title(fig_title);

